@@ -17,7 +17,7 @@
 import dataclasses
 import json  # type: ignore
 import re
-from typing import Callable, Dict, List, Optional, Sequence, Tuple, Union
+from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Union
 import warnings
 
 from google.api_core import gapic_v1, path_template, rest_helpers, rest_streaming
@@ -237,7 +237,7 @@ class AddressValidationRestTransport(AddressValidationTransport):
         def __hash__(self):
             return hash("ProvideValidationFeedback")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -262,7 +262,6 @@ class AddressValidationRestTransport(AddressValidationTransport):
                     request (~.address_validation_service.ProvideValidationFeedbackRequest):
                         The request object. The request for sending validation
                     feedback.
-
                     retry (google.api_core.retry.Retry): Designation of what errors, if any,
                         should be retried.
                     timeout (float): The timeout for this request.
@@ -344,7 +343,7 @@ class AddressValidationRestTransport(AddressValidationTransport):
         def __hash__(self):
             return hash("ValidateAddress")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -368,7 +367,6 @@ class AddressValidationRestTransport(AddressValidationTransport):
                 request (~.address_validation_service.ValidateAddressRequest):
                     The request object. The request for validating an
                 address.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
